@@ -13,15 +13,6 @@ from mopidy.backends.base import Backend
 
 logger = logging.getLogger('mopidy.gstreamer')
 
-default_caps = gst.Caps("""
-    audio/x-raw-int,
-    endianness=(int)1234,
-    channels=(int)2,
-    width=(int)16,
-    depth=(int)16,
-    signed=(boolean)true,
-    rate=(int)44100""")
-
 
 class GStreamer(ThreadingActor):
     """
@@ -34,6 +25,15 @@ class GStreamer(ThreadingActor):
     """
 
     def __init__(self):
+        super(GStreamer, self).__init__()
+        self._default_caps = gst.Caps("""
+            audio/x-raw-int,
+            endianness=(int)1234,
+            channels=(int)2,
+            width=(int)16,
+            depth=(int)16,
+            signed=(boolean)true,
+            rate=(int)44100""")
         self._pipeline = None
         self._source = None
         self._tee = None
@@ -77,12 +77,14 @@ class GStreamer(ThreadingActor):
     def _on_new_source(self, element, pad):
         self._source = element.get_property('source')
         try:
-            self._source.set_property('caps', default_caps)
+            self._source.set_property('caps', self._default_caps)
         except TypeError:
             pass
 
     def _on_new_pad(self, source, pad, target_pad):
         if not pad.is_linked():
+            if target_pad.is_linked():
+                target_pad.get_peer().unlink(target_pad)
             pad.link(target_pad)
 
     def _on_message(self, bus, message):
@@ -333,7 +335,8 @@ class GStreamer(ThreadingActor):
         self._tee.send_event(event)
 
     def _handle_event_probe(self, teesrc, event):
-        if event.type == gst.EVENT_CUSTOM_DOWNSTREAM and event.has_name('mopidy-unlink-tee'):
+        if (event.type == gst.EVENT_CUSTOM_DOWNSTREAM
+                and event.has_name('mopidy-unlink-tee')):
             data = self._get_structure_data(event.get_structure())
 
             output = teesrc.get_peer().get_parent()
