@@ -3,9 +3,6 @@ import signal
 import thread
 import threading
 
-import gobject
-gobject.threads_init()
-
 from pykka import ActorDeadError
 from pykka.registry import ActorRegistry
 
@@ -25,9 +22,17 @@ def exit_handler(signum, frame):
     logger.info(u'Got %s signal', signals[signum])
     exit_process()
 
-def stop_all_actors():
+def stop_actors_by_class(klass):
+    actors = ActorRegistry.get_by_class(klass)
+    logger.debug(u'Stopping %d instance(s) of %s', len(actors), klass.__name__)
+    for actor in actors:
+        actor.stop()
+
+def stop_remaining_actors():
     num_actors = len(ActorRegistry.get_all())
     while num_actors:
+        logger.error(
+            u'There are actor threads still running, this is probably a bug')
         logger.debug(u'Seeing %d actor and %d non-actor thread(s): %s',
             num_actors, threading.active_count() - num_actors,
             ', '.join([t.name for t in threading.enumerate()]))
@@ -60,25 +65,3 @@ class BaseThread(threading.Thread):
 
     def run_inside_try(self):
         raise NotImplementedError
-
-
-class GObjectEventThread(BaseThread):
-    """
-    A GObject event loop which is shared by all Mopidy components that uses
-    libraries that need a GObject event loop, like GStreamer and D-Bus.
-
-    Should be started by Mopidy's core and used by
-    :mod:`mopidy.output.gstreamer`, :mod:`mopidy.frontend.mpris`, etc.
-    """
-
-    def __init__(self):
-        super(GObjectEventThread, self).__init__()
-        self.name = u'GObjectEventThread'
-        self.loop = None
-
-    def run_inside_try(self):
-        self.loop = gobject.MainLoop().run()
-
-    def destroy(self):
-        self.loop.quit()
-        super(GObjectEventThread, self).destroy()
