@@ -1,6 +1,6 @@
 from mopidy.utils.path import path_to_uri
 
-from tests import data_folder
+from tests import path_to_data_dir
 
-song = data_folder('song%s.wav')
+song = path_to_data_dir('song%s.wav')
 generate_song = lambda i: path_to_uri(song % i)
